![Credits to: https://voniart.weebly.com/cubist-animals.html](https://img.shields.io/github/last-commit/apachaves/Cubist)
![](https://img.shields.io/github/languages/code-size/apachaves/Cubist)

<img src='https://voniart.weebly.com/uploads/1/2/3/9/12399176/7832674_orig.jpg' width=125 height=125 align="right">

# Cubist

A Python package for fitting Quinlan's Cubist regression model.

Inspired by the R wrapper for cubist: https://github.com/topepo/Cubist


## Building
`python3 -m build --sdist --wheel .`

## Installing
`pip3 install .`

#### Help is welcome!

## Interesting Links:  
- https://www.linkedin.com/pulse/machine-learning-example-r-using-cubist-kirk-mettler
http://rulequest.com/cubist-info.html
